@@ -1,11 +1,14 @@
 package Exporter::Extensible;
-BEGIN { $Exporter::Extensible::VERSION = '0.05'; }
 use v5.12;
 use strict;
 use warnings;
+use Scalar::Util;
 require MRO::Compat if $] lt '5.009005';
 require mro;
 
+# ABSTRACT: Create easy-to-extend modules which export symbols
+our $VERSION = '0.06'; # VERSION
+
 our %EXPORT_PKG_CACHE;
 our %EXPORT_TAGS_PKG_CACHE;
 
@@ -177,8 +180,9 @@ sub import {
 		# Then pass that list to the installer (or uninstaller)
 		$self->$method(\@flat_install);
 		# If scope requested, create the scope-guard object
-		if (my $scope= delete $self->{scope}) {
+		if (my $scope= $self->{scope}) {
 			$$scope= bless [ $self, \@flat_install ], 'Exporter::Extensible::UnimportScopeGuard';
+			Scalar::Util::weaken($self->{scope});
 		}
 		# It's entirely likely that a generator might curry $self inside the sub it generated.
 		# So, we end up with a circular reference if we're holding onto the set of all things we
@@ -675,6 +679,8 @@ sub exporter_export {
 
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -685,7 +691,7 @@ Exporter::Extensible - Create easy-to-extend modules which export symbols
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -1332,8 +1338,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__END__
-
-# ABSTRACT: Create easy-to-extend modules which export symbols
-
